@@ -30,10 +30,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <libgames-support/games-conf.h>
 #include <libgames-support/games-gridframe.h>
-#include <libgames-support/games-help.h>
-#include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-pause-action.h>
@@ -57,6 +54,8 @@
 #define DEFAULT_WIDTH 650
 #define DEFAULT_HEIGHT 520
 
+GSettings *settings;
+GSettings *worm_settings[NUMWORMS];
 GtkWidget *window;
 GtkWidget *statusbar;
 GtkWidget *notebook;
@@ -172,7 +171,7 @@ about_cb (GtkAction * action, gpointer data)
        "authors", authors,
        "documenters", documenters, "translator-credits",
        _("translator-credits"), "logo-icon-name",
-       "gnome-gnibbles", "website",
+       "gnibbles", "website",
        "http://www.gnome.org/projects/gnome-games/",
        "website-label", _("GNOME Games web site"),
        "wrap-license", TRUE, NULL);
@@ -593,7 +592,12 @@ show_cursor_cb (GtkWidget * widget, GdkEventMotion *event, gpointer data)
 static void
 help_cb (GtkAction * action, gpointer data)
 {
-  games_help_display (window, "gnibbles", NULL);
+  GError *error = NULL;
+
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (window)), "ghelp:gnibbles", gtk_get_current_event_time (), &error);
+  if (error)
+    g_warning ("Failed to show help: %s", error->message);
+  g_clear_error (&error);
 }
 
 static const GtkActionEntry action_entry[] = {
@@ -696,7 +700,7 @@ setup_window (void)
 
   gtk_window_set_default_size (GTK_WINDOW (window),
                                DEFAULT_WIDTH, DEFAULT_HEIGHT);
-  games_conf_add_window (GTK_WINDOW (window), KEY_PREFERENCES_GROUP);
+  //games_conf_add_window (GTK_WINDOW (window), KEY_PREFERENCES_GROUP);
 
   g_signal_connect (G_OBJECT (window), "destroy",
                     G_CALLBACK (gtk_main_quit), NULL);
@@ -884,17 +888,11 @@ main (int argc, char **argv)
 {
   GOptionContext *context;
   gboolean retval;
+  int i;
   GError *error = NULL;
 
-  if (!games_runtime_init ("gnibbles"))
-    return 1;
-
-#ifdef ENABLE_SETGID
-  setgid_io_init ();
-#endif
-
   g_set_application_name (_("Nibbles"));
-
+  
   if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS) {
     GtkWidget *dialog = gtk_message_dialog_new (NULL,
                                                 GTK_DIALOG_MODAL,
@@ -907,6 +905,14 @@ main (int argc, char **argv)
     exit (1);
   }
 
+  settings = g_settings_new ("org.gnome.gnibbles");
+  for (i = 0; i < NUMWORMS; i++)
+  {
+    gchar *name = g_strdup_printf ("org.gnome.gnibbles.worm%d", i);
+    worm_settings[i] = g_settings_new (name);
+    g_free (name);
+  }
+
   context = g_option_context_new (NULL);
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
@@ -919,7 +925,7 @@ main (int argc, char **argv)
     exit (1);
   }
 
-  gtk_window_set_default_icon_name ("gnome-gnibbles");
+  gtk_window_set_default_icon_name ("gnibbles");
   srand (time (NULL));
 
   highscores = games_scores_new ("gnibbles",
@@ -928,7 +934,6 @@ main (int argc, char **argv)
                                  0 /* default category */,
                                  GAMES_SCORES_STYLE_PLAIN_DESCENDING);
 
-  games_conf_initialise ("Gnibbles");
   properties = gnibbles_properties_new ();
   setup_window ();
   gnibbles_load_pixmap (properties->tilesize);
@@ -941,9 +946,6 @@ main (int argc, char **argv)
   gtk_main ();
 
   gnibbles_properties_destroy (properties);
-  games_conf_shutdown ();
-
-  games_runtime_shutdown ();
 
   return 0;
 }
